# QWnet Package

This package provides a unified interface for various Quantum Walk simulations.

## Installation

```bash
pip install QWnet
```

## Usage

```python
import QWnet as qw

# 1D/2D/3D Lattice Walks
qw.run_simulation('1d', steps=100)
qw.run_simulation('2d', steps=50)
qw.run_simulation('3d', steps=20)

# Graph Walks
qw.run_simulation('ChawlaQW', file_path='graph.edgelist', steps=100)
qw.run_simulation('QPageRank', steps=20, alpha=0.85)
qw.run_simulation('HadamardQW', steps=100, top_p=0.05)
qw.run_simulation('SzegedyQW', steps=10)
qw.run_simulation('directSumQW', initial_state='uniform', coin_type='fourier')
```
